@@ -9,8 +9,9 @@ NULL
 ## quiets concerns of R CMD check re: the .'s that appear in pipelines
 if (getRversion() >= "2.15.1") {
   utils::globalVariables(c(
-    ".", "breaks",
+    ".", "breaks", "Levels", "varyable", "count",
     "cumulative", "frequency", "values", "s", "tp", "type", "xvar", "yvar",
-    "data", "varnames", "frequency", "varname", "bins", "n", "value", "y", "count"
+    "data", "varnames", "frequency", "varname", "bins", "n", "value", "y", "
+    count"
   ))
 }
