@@ -1,14 +1,15 @@
 #' Frequency table
 #'
-#' Frequency table for categorical and continuous data and returns the 
-#' frequency, cumulative frequency, frequency percent and cumulative frequency 
-#' percent. \code{plot.ds_freq_table()} creates bar plot for the categorical 
+#' Frequency table for categorical and continuous data and returns the
+#' frequency, cumulative frequency, frequency percent and cumulative frequency
+#' percent. \code{plot.ds_freq_table()} creates bar plot for the categorical
 #' data and histogram for continuous data.
-#' 
+#'
 #' @param data A \code{data.frame} or a \code{tibble}.
 #' @param variable Column in \code{data}.
 #' @param x An object of class \code{ds_freq_table}.
 #' @param bins Number of intervals into which the data must be split.
+#' @param print_plot logical; if \code{TRUE}, prints the plot else returns a plot object.
 #' @param ... Further arguments to be passed to or from methods.
 #'
 #' @examples
@@ -33,7 +34,7 @@
 ds_freq_table <- function(data, variable, bins = 5) UseMethod("ds_freq_table")
 
 #' @export
-#' 
+#'
 ds_freq_table.default <- function(data, variable, bins = 5) {
 
 	varyable <- rlang::enquo(variable)
@@ -62,25 +63,35 @@ print.ds_freq_table <- function(x, ...) {
 
 	nx <- length(x)
 	if (nx == 5) {
-		print_ftable(x)	
+		print_ftable(x)
 	} else if (nx == 11) {
 		print_fcont(x)
 	} else {
 		NULL
 	}
-  
+
 }
 
 #' @rdname ds_freq_table
 #' @export
 #'
-plot.ds_freq_table <- function(x, ...) {
+plot.ds_freq_table <- function(x, print_plot = TRUE, ...) {
 
 	nx <- length(x)
 	if (nx == 5) {
-		plot_ds_freq_factor(x)
+		p <- plot_ds_freq_factor(x)
+		if (print_plot) {
+		  print(p)
+		} else {
+		  return(p)
+		}
 	} else if (nx == 11) {
-		plot_ds_freq_numeric(x)
+		p <- plot_ds_freq_numeric(x)
+		if (print_plot) {
+		  print(p)
+		} else {
+		  return(p)
+		}
 	} else {
 		NULL
 	}
@@ -94,4 +105,4 @@ plot.ds_freq_table <- function(x, ...) {
 ds_freq_cont <- function(data, variable, bins) {
   .Deprecated("ds_freq_table()")
   ds_freq_table(data, variable, bins)
-}
\ No newline at end of file
+}
