@@ -32,6 +32,7 @@ test_that("ds_rindex returns the appropriate error", {
 
 test_that("output from ds_skewness matches expected result", {
   expect_equal(round(ds_skewness(mtcars$mpg), 3), 0.672)
+  expect_equal(round(ds_skewness(mpg, mtcars), 3), 0.672)
   expect_equal(round(ds_skewness(mtcars$disp), 3), 0.420)
   expect_equal(round(ds_skewness(mtcars$hp), 3), 0.799)
   expect_equal(round(ds_skewness(mtcars$drat), 3), 0.293)
@@ -41,13 +42,14 @@ test_that("output from ds_skewness matches expected result", {
 
 
 test_that("ds_skewness returns the appropriate error", {
-  expect_error(round(ds_skewness("mtcars$mpg"), 3), "x must be numeric")
-  expect_error(round(ds_skewness(as.factor(mtcars$mpg)), 3), "x must be numeric")
+  expect_error(round(ds_skewness("mtcars$mpg"), 3), "Skewness is calculated only for numeric data. The variable you have selected is of type character.")
+  expect_error(round(ds_skewness(as.factor(mtcars$mpg)), 3), "Skewness is calculated only for numeric data. The variable you have selected is of type factor.")
 })
 
 
 test_that("output from ds_kurtosis matches expected result", {
   expect_equal(round(ds_kurtosis(mtcars$mpg), 3), -0.022)
+  expect_equal(round(ds_kurtosis(mpg, mtcars), 3), -0.022)
   expect_equal(round(ds_kurtosis(mtcars$disp), 3), -1.068)
   expect_equal(round(ds_kurtosis(mtcars$hp), 3), 0.275)
   expect_equal(round(ds_kurtosis(mtcars$drat), 3), -0.450)
@@ -57,13 +59,14 @@ test_that("output from ds_kurtosis matches expected result", {
 
 
 test_that("ds_kurtosis returns the appropriate error", {
-  expect_error(round(ds_kurtosis("mtcars$mpg"), 3), "x must be numeric")
-  expect_error(round(ds_kurtosis(as.factor(mtcars$mpg)), 3), "x must be numeric")
+  expect_error(round(ds_kurtosis("mtcars$mpg"), 3), "Kurtosis is calculated only for numeric data. The variable you have selected is of type character.")
+  expect_error(round(ds_kurtosis(as.factor(mtcars$mpg)), 3), "Kurtosis is calculated only for numeric data. The variable you have selected is of type factor.")
 })
 
 
 test_that("ds_css matches `Sum Sq` from anova", {
   expect_equal(round(ds_css(mtcars$mpg)), round(anova(lm(mpg ~ 1, data = mtcars))[[2]]))
+  expect_equal(round(ds_css(mpg, mtcars)), round(anova(lm(mpg ~ 1, data = mtcars))[[2]]))
   expect_equal(round(ds_css(mtcars$disp)), round(anova(lm(disp ~ 1, data = mtcars))[[2]]))
   expect_equal(round(ds_css(mtcars$hp)), round(anova(lm(hp ~ 1, data = mtcars))[[2]]))
   expect_equal(round(ds_css(mtcars$drat)), round(anova(lm(drat ~ 1, data = mtcars))[[2]]))
@@ -73,20 +76,21 @@ test_that("ds_css matches `Sum Sq` from anova", {
 
 
 test_that("ds_css returns the appropriate error", {
-  expect_error(round(ds_css("mtcars$mpg")), "x must be numeric")
-  expect_error(round(ds_css(as.factor(mtcars$mpg))), "x must be numeric")
+  expect_error(round(ds_css("mtcars$mpg")), "Corrected sum of squares can be calculated only for numeric data. The variable you have selected is of type character.")
+  expect_error(round(ds_css(as.factor(mtcars$mpg))), "Corrected sum of squares can be calculated only for numeric data. The variable you have selected is of type factor.")
 })
 
 
 test_that("output from ds_cvar matches the expected result", {
   expect_equal(round(ds_cvar(mtcars$mpg), 3), 29.999)
+  expect_equal(round(ds_cvar(mpg, mtcars), 3), 29.999)
   expect_equal(round(ds_cvar(mtcars$disp), 3), 53.718)
 })
 
 
 test_that("ds_cvar returns the appropriate error", {
-  expect_error(ds_cvar("mtcars$mpg"), "x must be numeric")
-  expect_error(ds_cvar(as.factor(mtcars$mpg)), "x must be numeric")
+  expect_error(ds_cvar("mtcars$mpg"), "Coefficient of variation is calculated only for numeric data. The variable you have selected is of type character.")
+  expect_error(ds_cvar(as.factor(mtcars$mpg)), "Coefficient of variation is calculated only for numeric data. The variable you have selected is of type factor.")
 })
 
 
@@ -108,6 +112,7 @@ test_that("ds_mode returns the appropriate error", {
 
 test_that("output from ds_range matches the expected result", {
   expect_equal(ds_range(mtcars$mpg), 23.5)
+  expect_equal(ds_range(mpg, mtcars), 23.5)
   expect_equal(ds_range(mtcars$disp), 400.9)
   expect_equal(ds_range(mtcars$hp), 283)
   expect_equal(ds_range(mtcars$drat), 2.17)
@@ -117,13 +122,14 @@ test_that("output from ds_range matches the expected result", {
 
 
 test_that("ds_range returns the appropriate error", {
-  expect_error(ds_range("mtcars$mpg"), "data must be numeric")
-  expect_error(ds_range(as.factor(mtcars$mpg)), "data must be numeric")
+  expect_error(ds_range("mtcars$mpg"), "Range can be calculated only for numeric data. The variable you have selected is character.")
+  expect_error(ds_range(as.factor(mtcars$mpg)), "Range can be calculated only for numeric data. The variable you have selected is factor.")
 })
 
 
 test_that("output from ds_mdev matches the expected result", {
   expect_equal(round(ds_mdev(mtcars$mpg), 3), 4.714)
+  expect_equal(round(ds_mdev(mpg, mtcars), 3), 4.714)
   expect_equal(round(ds_mdev(mtcars$disp), 3), 108.786)
   expect_equal(round(ds_mdev(mtcars$hp), 3), 56.48)
   expect_equal(round(ds_mdev(mtcars$drat), 3), 0.453)
@@ -138,33 +144,35 @@ test_that("output from ds_mdev matches the expected result", {
 })
 
 test_that("ds_mdev returns the appropriate error", {
-  expect_error(ds_mdev("mtcars$mpg"), "x must be numeric")
-  expect_error(ds_mdev(as.factor(mtcars$mpg)), "x must be numeric")
+  expect_error(ds_mdev("mtcars$mpg"), "Mean absolute deviation is calculated only for numeric data. The variable you have selected is of type character.")
+  expect_error(ds_mdev(as.factor(mtcars$mpg)), "Mean absolute deviation is calculated only for numeric data. The variable you have selected is of type factor.")
 })
 
 
 test_that("output from ds_hmean matches the expected output", {
   expect_equal(round(ds_hmean(mtcars$mpg), 2), 18.44)
+  expect_equal(round(ds_hmean(mpg, mtcars), 2), 18.44)
   expect_equal(round(ds_hmean(mtcars$disp), 2), 166.8)
   expect_equal(round(ds_hmean(mtcars$hp), 2), 118.23)
 })
 
 test_that("ds_hmean throws the appropriate error", {
-  expect_error(ds_hmean("mtcars$mpg"), "x must be numeric")
-  expect_error(ds_hmean(as.factor(mtcars$mpg)), "x must be numeric")
+  expect_error(ds_hmean("mtcars$mpg"), "Harmonic mean can be calculated only for numeric data. The variable you have selected is character.")
+  expect_error(ds_hmean(as.factor(mtcars$mpg)), "Harmonic mean can be calculated only for numeric data. The variable you have selected is factor.")
 })
 
 
 test_that("output from ds_gmean matches the expected output", {
   expect_equal(round(ds_gmean(mtcars$mpg), 2), 19.25)
+  expect_equal(round(ds_gmean(mpg, mtcars), 2), 19.25)
   expect_equal(round(ds_gmean(mtcars$disp), 2), 197.32)
   expect_equal(round(ds_gmean(mtcars$hp), 2), 131.88)
 })
 
 
 test_that("ds_gmean throws the appropriate error", {
-  expect_error(ds_gmean("mtcars$mpg"), "x must be numeric")
-  expect_error(ds_gmean(as.factor(mtcars$mpg)), "x must be numeric")
+  expect_error(ds_gmean("mtcars$mpg"), "Geometric mean can be calculated only for numeric data. The variable you have selected is of type character.")
+  expect_error(ds_gmean(as.factor(mtcars$mpg)), "Geometric mean can be calculated only for numeric data. The variable you have selected is of type factor.")
 })
 
 test_that("output from ds_measures_location is as expected", {
